@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 from __future__ import absolute_import, unicode_literals
 from cryptography.hazmat.primitives.ciphers import Cipher, algorithms, modes
-from cryptography.hazmat.backends import default_backend
 
 
 class BaseWeChatCipher(object):
@@ -22,12 +21,10 @@ class WeChatCipher(BaseWeChatCipher):
 
     def __init__(self, key, iv=None):
         iv = iv or key[:16]
-        backend = default_backend()
         super(WeChatCipher, self).__init__(
             Cipher(
                 algorithms.AES(key),
                 modes.CBC(iv),
-                backend=backend
             )
         )
 
@@ -35,11 +32,9 @@ class WeChatCipher(BaseWeChatCipher):
 class AesEcbCipher(BaseWeChatCipher):
 
     def __init__(self, key):
-        backend = default_backend()
         super(AesEcbCipher, self).__init__(
             Cipher(
                 algorithms.AES(key),
                 modes.ECB(),
-                backend=backend
             )
         )
